@@ -20,11 +20,13 @@ def main():
 
 
 class Entsoe():
-    def __init__(self, token, date_chunksize=30, batch_size=350, max_workers=24):
+    _error_list=[]
+    def __init__(self, token, date_chunksize=30, batch_size=350, max_workers=12):
         self._token = token
         self._chunksize = date_chunksize
         self._batchsize = batch_size
         self._max_workers = max_workers
+        self._error_list=[]
 
     def dayahead_prices_df(self, countries, start_date, end_date):
         import pandas as pd
@@ -105,6 +107,7 @@ class Entsoe():
 
     def actual_production(self, country, start_date, end_date=datetime(2030, 12, 31)):
         in_list = self._get_actual_production(country, start_date, end_date)
+        print(Entsoe._error_list)
         return in_list
 
     def _get_actual_production(self, country, start_date, end_date):
@@ -123,7 +126,7 @@ class Entsoe():
             url = f'{base_url}{doc_url}'
             tasks.append((url, country))
         indata_list = []
-        batch_size = 50
+        batch_size = 60
         batch_duration = 10
         batches = len(tasks) // batch_size
         for batch in range(batches + 1):
@@ -133,15 +136,18 @@ class Entsoe():
                 indata_list += [Entsoe._read_xml_A73(indata[0], indata[1]) for indata in batch_list]
             duration = datetime.utcnow().timestamp() - st
             if duration < batch_duration and batch < batches:
-                # print(f'waiting for {batch_duration-duration} after batch {batch} of {batches} with batch_duration={batch_duration}')
+                print(f'waiting for {batch_duration-duration} after batch {batch} of {batches} with batch_duration={batch_duration}')
                 time.sleep(batch_duration - duration)
         indata_list = utils.flatten_list(indata_list)
         return indata_list
 
     @classmethod
     def _read_xml_A73(cls, indata_xml, country):
-        indata_json = json.dumps(xmltodict.parse(indata_xml))
-        indata_dict = json.loads(indata_json)
+        try:
+            indata_json = json.dumps(xmltodict.parse(indata_xml))
+            indata_dict = json.loads(indata_json)
+        except:
+            indata_dict={}
         out_list = []
         if 'GL_MarketDocument' in indata_dict.keys():
             timeseries = indata_dict['GL_MarketDocument']['TimeSeries']
@@ -165,7 +171,12 @@ class Entsoe():
 
     @classmethod
     def _get_xml(cls, task):
-        indata_xml = requests.get(task[0]).text
+        print(task[0])
+        try:
+            indata_xml = requests.get(task[0]).text
+        except:
+            cls._error_list.append(task)
+            indata_xml= ''
         return indata_xml, task[1]
 
     @classmethod
